==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/CascadeDeleteArray.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
using com.db4o.ext;
namespace com.db4o.test {

   public class CascadeDeleteArray {
      
      public CascadeDeleteArray() : base() {
      }
      internal ArrayElem[] elements;
      
      public void configure() {
         Db4o.configure().objectClass(this).cascadeOnDelete(true);
      }
      
      public void storeOne() {
        elements = new ArrayElem[]{
            new ArrayElem("one"),
            new ArrayElem("two"),
            new ArrayElem("three")         
        };
      }
      
      public void testOne() {
         Tester.ensureOccurrences(typeof(ArrayElem), 3);
         Tester.delete(this);
         Tester.ensureOccurrences(typeof(ArrayElem), 0);
         Tester.rollBack();
         Tester.ensureOccurrences(typeof(ArrayElem), 3);
         Tester.delete(this);
         Tester.ensureOccurrences(typeof(ArrayElem), 0);
         Tester.commit();
         Tester.ensureOccurrences(typeof(ArrayElem), 0);
      }
      
      public class ArrayElem {
         internal String name;
         
         public ArrayElem() : base() {
         }
         
         public ArrayElem(String name) : base() {
            this.name = name;
         }
      }
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/CascadeDeleteArray.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
using com.db4o.ext;
namespace com.db4o.test {

   public class CascadeDeleteArray {
      
      public CascadeDeleteArray() : base() {
      }
      internal ArrayElem[] elements;
      
      public void Configure() {
         Db4o.Configure().ObjectClass(this).CascadeOnDelete(true);
      }
      
      public void StoreOne() {
        elements = new ArrayElem[]{
            new ArrayElem("one"),
            new ArrayElem("two"),
            new ArrayElem("three")         
        };
      }
      
      public void TestOne() {
         Tester.EnsureOccurrences(typeof(ArrayElem), 3);
         Tester.Delete(this);
         Tester.EnsureOccurrences(typeof(ArrayElem), 0);
         Tester.RollBack();
         Tester.EnsureOccurrences(typeof(ArrayElem), 3);
         Tester.Delete(this);
         Tester.EnsureOccurrences(typeof(ArrayElem), 0);
         Tester.Commit();
         Tester.EnsureOccurrences(typeof(ArrayElem), 0);
      }
      
    }

    public class ArrayElem {
        internal String name;
        
        public ArrayElem() : base() {
        }
        
        public ArrayElem(String name) : base() {
        this.name = name;
        }
    }
}
